summaryrefslogtreecommitdiffstats
path: root/bugzilla/base.py
diff options
context:
space:
mode:
authorWill Woods <wwoods@redhat.com>2008-08-18 13:40:25 -0400
committerWill Woods <wwoods@redhat.com>2008-08-18 13:40:25 -0400
commit772bb9f201521535df57fa8b37d2da2af1c3a5fb (patch)
treef34237ded85f6e92723ab405d55ceffc10477db8 /bugzilla/base.py
parentff1ce61e55ae0b2f5e8fb30d39c77f8bdddfe4fa (diff)
downloadpython-bugzilla-772bb9f201521535df57fa8b37d2da2af1c3a5fb.tar.gz
python-bugzilla-772bb9f201521535df57fa8b37d2da2af1c3a5fb.tar.xz
python-bugzilla-772bb9f201521535df57fa8b37d2da2af1c3a5fb.zip
Fix up _updatecc - change the action param to match other methods and implement it for bz32.
Diffstat (limited to 'bugzilla/base.py')
-rw-r--r--bugzilla/base.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/bugzilla/base.py b/bugzilla/base.py
index 8158998..db9b2e9 100644
--- a/bugzilla/base.py
+++ b/bugzilla/base.py
@@ -479,16 +479,18 @@ class BugzillaBase(object):
def _updatedeps(self,id,blocked,dependson,action):
'''IMPLEMENT ME: update the deps (blocked/dependson) for the given bug.
blocked, dependson: list of bug ids/aliases
- action: 'add' or 'remove'
+ action: 'add' or 'delete'
'''
raise NotImplementedError
def _updatecc(self,id,cclist,action,comment='',nomail=False):
'''IMPLEMENT ME: Update the CC list using the action and account list
specified.
cclist must be a list (not a tuple!) of addresses.
action may be 'add', 'remove', or 'makeexact'.
comment specifies an optional comment to add to the bug.
if mail is True, email will be generated for this change.
+ Note that using 'overwrite' may result in up to three XMLRPC calls
+ (fetch list, remove each element, add new elements). Avoid if possible.
'''
raise NotImplementedError
def _updatewhiteboard(self,id,text,which,action):
@@ -479,16 +479,18 @@ class BugzillaBase(object):
specified.
cclist must be a list (not a tuple!) of addresses.
- action may be 'add', 'remove', or 'makeexact'.
+ action may be 'add', 'delete', or 'overwrite'.
comment specifies an optional comment to add to the bug.
if mail is True, email will be generated for this change.